searchData={"content_type":"text/markdown","items":[{"doc":"Module to manage reactive state by using GenServer processes (\"reactive process\" from here on) to manage each piece of state and its relationships to other reactive processes","ref":"Reactive.html","title":"Reactive","type":"module"},{"doc":"The package can be installed by adding `reactive_state` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:reactive_state, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"Reactive.html#module-installation","title":"Installation - Reactive","type":"module"},{"doc":"#","ref":"Reactive.html#module-examples","title":"Examples - Reactive","type":"module"},{"doc":"iex> use Reactive\n    iex> ref = Ref.new(0) #PID \n    iex> Ref.get(ref) # or Ref.get(ref)\n    0\n    iex> Ref.set(ref, 1)\n    :ok\n    iex> Ref.get(ref)\n    1\n\n#","ref":"Reactive.html#module-working-with-data-directly-with-reactive-ref","title":"Working with data directly with `Reactive.Ref` - Reactive","type":"module"},{"doc":"iex> use Reactive\n    iex> ref = Ref.new(2)\n    iex> ref_squared = reactive do\n    ...>   get(ref) ** 2\n    ...> end\n    iex> Reactive.get(ref_squared)\n    4\n    iex> Ref.set(ref, 3)\n    iex> Reactive.get(ref_squared)\n    9\n\n##","ref":"Reactive.html#module-reactive-block","title":"Reactive Block - Reactive","type":"module"},{"doc":"iex> use Reactive\n    iex> if_false = Ref.new(1)\n    iex> if_true = Ref.new(2)\n    iex> toggle = Ref.new(false)\n    iex> computed = reactive do\n    ...>   if get(toggle) do\n    ...>     get(if_true)\n    ...>   else\n    ...>     get(if_false)\n    ...>   end\n    ...> end\n    iex> Reactive.get(computed)\n    1\n    iex> Ref.set(toggle, true)\n    :ok\n    iex> Reactive.get(computed)\n    2\n    iex> # Now, updating `if_false` will not require a recomputation\n    iex> Ref.set(if_false, 0)\n    :ok\n    iex> Reactive.get_cached(computed)\n    2\n    iex> # Updating `if_true` will require a recomputation\n    iex> Ref.set(if_true, 3)\n    :ok\n    iex> Reactive.get_cached(computed)\n    :stale\n    iex> Reactive.get(computed)\n    3","ref":"Reactive.html#module-conditional-branches","title":"Conditional Branches - Reactive","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Reactive.html#child_spec/1","title":"Reactive.child_spec/1","type":"function"},{"doc":"Retrieve the state of a reactive process","ref":"Reactive.html#get/1","title":"Reactive.get/1","type":"function"},{"doc":"iex> ref = Reactive.new(fn _ -> 0 end)\n    iex> Reactive.get(ref)\n    0","ref":"Reactive.html#get/1-example","title":"Example - Reactive.get/1","type":"function"},{"doc":"Retrieve the state of a reactive process, and register the current process as dependent of that process, with the call ID of the current process.\nYou should use the `Reactive.reactive` macro to manage reactive relationships instead","ref":"Reactive.html#get/2","title":"Reactive.get/2","type":"function"},{"doc":"iex> use Reactive\n    iex> ref = reactive do\n    ...>   0\n    ...> end\n    iex> Reactive.get(ref)\n    0","ref":"Reactive.html#get/2-example","title":"Example - Reactive.get/2","type":"function"},{"doc":"Retrieve the cached state of a reactive process, or :stale if it has not been computed or is stale","ref":"Reactive.html#get_cached/1","title":"Reactive.get_cached/1","type":"function"},{"doc":"iex> use Reactive\n    iex> ref = reactive do\n    ...>   0\n    ...> end\n    iex> Reactive.get_cached(ref)\n    :stale\n    iex> Reactive.get(ref)\n    0\n    iex> Reactive.get_cached(ref)\n    0","ref":"Reactive.html#get_cached/1-example","title":"Example - Reactive.get_cached/1","type":"function"},{"doc":"Create a reactive process using a method\n\n    iex> use Reactive\n    iex> ref = Ref.new(2)\n    iex> ref_squared = Reactive.new(fn call_id ->\n    ...>   Reactive.get(ref, call_id) ** 2\n    ...> end)\n    iex> Reactive.get(ref_squared)\n    4","ref":"Reactive.html#new/1","title":"Reactive.new/1","type":"function"},{"doc":"Syntatic sugar for creating reactive blocks\n\n    iex> use Reactive\n    iex> ref = Ref.new(2)\n    iex> ref_squared = reactive do\n    ...>   get(ref) ** 2\n    ...> end #PID \n    iex> Reactive.get(ref_squared)\n    4\n    iex> Ref.set(ref, 3)\n    iex> Reactive.get(ref_squared)\n    9\n\nUsing the `reactive` macro in this way is roughly equivalent to:\n\n    iex> use Reactive\n    iex> ref = Ref.new(2)\n    iex> ref_squared = Reactive.new(fn call_id ->\n    ...>   Reactive.get(ref, call_id) ** 2\n    ...> end)\n    iex> Reactive.get(ref_squared)\n    4\n    iex> Ref.set(ref, 3)\n    iex> Reactive.get(ref_squared)\n    9","ref":"Reactive.html#reactive/1","title":"Reactive.reactive/1","type":"macro"},{"doc":"Replace a reactive process's computation method\n\n    iex> use Reactive\n    iex> ref = reactive do\n    ...>   0\n    ...> end\n    iex> Reactive.get(ref)\n    0\n    iex> Reactive.set(ref, fn _ -> 1 end)\n    :ok\n    iex> Reactive.get(ref)\n    1","ref":"Reactive.html#set/2","title":"Reactive.set/2","type":"function"},{"doc":"Wrapper to work with reactive state directly","ref":"Reactive.Ref.html","title":"Reactive.Ref","type":"module"},{"doc":"iex> use Reactive\n    iex> ref = Ref.new(0) #PID \n    iex> Ref.get(ref)\n    0\n    iex> Ref.set(ref, 1)\n    :ok\n    iex> Ref.get(ref)\n    1","ref":"Reactive.Ref.html#module-example","title":"Example - Reactive.Ref","type":"module"},{"doc":"Retrieve the state of a reactive process","ref":"Reactive.Ref.html#get/1","title":"Reactive.Ref.get/1","type":"function"},{"doc":"iex> ref = Ref.new(0)\n    iex> Ref.get(ref)\n    0","ref":"Reactive.Ref.html#get/1-example","title":"Example - Reactive.Ref.get/1","type":"function"},{"doc":"Retrieve the state of a reactive process, and register the current process as dependent of that process, with the call ID of the current process.\nYou should use the `Reactive.reactive` macro to manage reactive relationships instead","ref":"Reactive.Ref.html#get/2","title":"Reactive.Ref.get/2","type":"function"},{"doc":"iex> ref = Ref.new(0)\n    iex> Ref.get(ref)\n    0","ref":"Reactive.Ref.html#get/2-example","title":"Example - Reactive.Ref.get/2","type":"function"},{"doc":"Create a reactive process","ref":"Reactive.Ref.html#new/1","title":"Reactive.Ref.new/1","type":"function"},{"doc":"iex> ref = Ref.new(0)\n    iex> Ref.get(ref)\n    0","ref":"Reactive.Ref.html#new/1-example","title":"Example - Reactive.Ref.new/1","type":"function"},{"doc":"Set the state for a reactive process","ref":"Reactive.Ref.html#set/2","title":"Reactive.Ref.set/2","type":"function"},{"doc":"iex> ref = Ref.new(0)\n    iex> Ref.set(ref, 1)\n    :ok\n    iex> Ref.get(ref)\n    1","ref":"Reactive.Ref.html#set/2-example","title":"Example - Reactive.Ref.set/2","type":"function"},{"doc":"Set the state for a reactive process through a function that receives the old value","ref":"Reactive.Ref.html#set_fn/2","title":"Reactive.Ref.set_fn/2","type":"function"},{"doc":"iex> ref = Ref.new(0)\n    iex> Ref.set_fn(ref, fn state -> state + 1 end)\n    :ok\n    iex> Ref.get(ref)\n    1","ref":"Reactive.Ref.html#set_fn/2-example","title":"Example - Reactive.Ref.set_fn/2","type":"function"}]}